# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from willowlabs.service_grpc.company_information import company_information_service_pb2 as willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2


class CompanyInformationStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get_company_ownership = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_ownership',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipResponse.FromString,
        )
    self.get_company_roles = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_roles',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleResponse.FromString,
        )
    self.get_basic_company_information = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_basic_company_information',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationResponse.FromString,
        )
    self.get_company_signatory_information = channel.unary_unary(
        '/willowlabs.services.company_information.CompanyInformation/get_company_signatory_information',
        request_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationRequest.SerializeToString,
        response_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationResponse.FromString,
        )


class CompanyInformationServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get_company_ownership(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_roles(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_basic_company_information(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_signatory_information(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CompanyInformationServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get_company_ownership': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_ownership,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.OwnershipResponse.SerializeToString,
      ),
      'get_company_roles': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_roles,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.RoleResponse.SerializeToString,
      ),
      'get_basic_company_information': grpc.unary_unary_rpc_method_handler(
          servicer.get_basic_company_information,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.BasicCompanyInformationResponse.SerializeToString,
      ),
      'get_company_signatory_information': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_signatory_information,
          request_deserializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationRequest.FromString,
          response_serializer=willowlabs_dot_service__grpc_dot_company__information_dot_company__information__service__pb2.SignatoryInformationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'willowlabs.services.company_information.CompanyInformation', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
